@@ -3,6 +3,9 @@
 
 #include "account/featuredtagsmodel.h"
 
+#include <QJsonDocument>
+#include <QNetworkReply>
+
 #include "account/accountmanager.h"
 #include "account/relationship.h"
 
@@ -70,19 +73,14 @@ void FeaturedTagsModel::fill()
             if (!tags.isEmpty()) {
                 QVector<QString> fetchedTags;
 
-                std::transform(tags.cbegin(), tags.cend(), std::back_inserter(fetchedTags), [=](const QVariant &value) -> auto {
+                std::ranges::transform(std::as_const(tags), std::back_inserter(fetchedTags), [=](const QVariant &value) -> auto {
                     return value.toJsonObject()["name"_L1].toString();
                 });
                 beginInsertRows({}, m_tags.size(), m_tags.size() + fetchedTags.size() - 1);
                 m_tags += fetchedTags;
                 endInsertRows();
             }
-        },
-        [](const QNetworkReply *reply) {
-            Q_UNUSED(reply)
-            // Note: we are silently failing here because some servers don't implement this endpoint
-            // See BUG: 484475 and https://docs.akkoma.dev/stable-docs/development/API/differences_in_mastoapi_responses/#featured-tags
         });
 }
 
-#include "moc_featuredtagsmodel.cpp"
\ No newline at end of file
+#include "moc_featuredtagsmodel.cpp"
