@@ -97,6 +97,11 @@ void Identity::setRelationship(Relationship *r)
     Q_EMIT relationshipChanged();
 }
 
+Identity *Identity::moved() const
+{
+    return m_movedIdentity;
+}
+
 void Identity::reparentIdentity(AbstractAccount *parent)
 {
     m_parent = parent;
@@ -126,6 +131,7 @@ void Identity::fromSourceData(const QJsonObject &doc)
     m_visibility = source["privacy"_L1].toString();
     m_lastStatusAt = QDate::fromString(doc["last_status_at"_L1].toString(), Qt::ISODate);
     m_createdAt = QDate::fromString(doc["created_at"_L1].toString(), Qt::ISODate);
+    m_limited = doc["limited"_L1].toBool();
 
     m_displayNameHtml = m_displayName.replace(QLatin1Char('<'), QStringLiteral("&lt;")).replace(QLatin1Char('>'), QStringLiteral("&gt;"));
 
@@ -158,6 +164,12 @@ void Identity::fromSourceData(const QJsonObject &doc)
         }
     }
 
+    if (doc.contains("moved"_L1)) {
+        m_movedIdentity = new Identity();
+        m_movedIdentity->setParent(m_parent);
+        m_movedIdentity->fromSourceData(doc["moved"_L1].toObject());
+    }
+
     Q_EMIT identityUpdated();
 }
 
@@ -186,4 +198,9 @@ QString Identity::createdAt() const
     return TextHandler::getRelativeDate(m_createdAt);
 }
 
+bool Identity::limited() const
+{
+    return m_limited;
+}
+
 #include "moc_identity.cpp"
