@@ -36,6 +36,8 @@ class Identity : public QObject
     Q_PROPERTY(QJsonArray fields READ fields NOTIFY identityUpdated)
     Q_PROPERTY(Relationship *relationship READ relationship NOTIFY relationshipChanged)
     Q_PROPERTY(QString createdAt READ createdAt NOTIFY identityUpdated)
+    Q_PROPERTY(bool limited READ limited NOTIFY identityUpdated)
+    Q_PROPERTY(Identity *moved READ moved NOTIFY identityUpdated)
 
 public:
     /**
@@ -127,6 +129,8 @@ public:
 
     [[nodiscard]] QString createdAt() const;
 
+    [[nodiscard]] bool limited() const;
+
     /**
      * @brief Fills in identity data from JSON.
      * @param doc The JSON data to load from.
@@ -150,6 +154,11 @@ public:
      */
     void setRelationship(Relationship *r);
 
+    /**
+     * @return The identity this account has moved to. Is null if the account hasn't moved.
+     */
+    Identity *moved() const;
+
 Q_SIGNALS:
     void relationshipChanged();
     void identityUpdated();
@@ -176,4 +185,6 @@ private:
     AbstractAccount *m_parent = nullptr;
     bool m_bot;
     QDate m_createdAt;
+    bool m_limited;
+    Identity *m_movedIdentity = nullptr;
 };
