@@ -17,6 +17,8 @@ class Preferences final : public QObject
     Q_PROPERTY(QString defaultLanguage READ defaultLanguage WRITE setDefaultLanguage NOTIFY defaultLanguageChanged)
     Q_PROPERTY(QString extendMedia READ extendMedia NOTIFY extendMediaChanged)
     Q_PROPERTY(bool extendSpoiler READ extendSpoiler NOTIFY extendSpoilerChanged)
+    Q_PROPERTY(bool indexable READ indexable WRITE setIndexable NOTIFY indexableChanged)
+    Q_PROPERTY(bool hideCollections READ hideCollections WRITE setHideCollections NOTIFY hideCollectionsChanged)
 
 public:
     explicit Preferences(AbstractAccount *account);
@@ -72,6 +74,32 @@ public:
      */
     [[nodiscard]] bool extendSpoiler() const;
 
+    /**
+     * @return Whether public posts should be indexed.
+     * @see setIndexable()
+     */
+    [[nodiscard]] bool indexable() const;
+
+    /**
+     * @brief Set whether public posts should be indexed.
+     * @param indexable Whether or not public posts are indexed.
+     * @see indexable()
+     */
+    void setIndexable(bool indexable);
+
+    /**
+     * @return Whether to hide followers and followed accounts.
+     * @see setHideCollections()
+     */
+    [[nodiscard]] bool hideCollections() const;
+
+    /**
+     * @brief Set whether to hide followers and followed accounts.
+     * @param hide Whether or not followers and followed accounts are shown.
+     * @see hideCollections()
+     */
+    void setHideCollections(bool hide);
+
 Q_SIGNALS:
     /**
      * @brief Emitted when the default status visibility preference has been changed.
@@ -101,6 +129,16 @@ Q_SIGNALS:
      */
     void extendSpoilerChanged();
 
+    /**
+     * @brief Emitted when the indexable preference has been changed.
+     */
+    void indexableChanged();
+
+    /**
+     * @brief Emitted when the hide collections preference has been changed.
+     */
+    void hideCollectionsChanged();
+
 private:
     void setPreferencesField(const QString &name, const QString &value);
 
@@ -111,4 +149,6 @@ private:
     QString m_defaultLanguage;
     QString m_extendMedia;
     bool m_extendSpoiler;
+    bool m_indexable;
+    bool m_hideCollections;
 };
