@@ -4,7 +4,8 @@
 
 #pragma once
 
-#include <QtQml>
+#include <QJsonArray>
+#include <QQmlEngine>
 
 class AbstractAccount;
 class Identity;
