@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "ipinfo.h"
+#include "admin/ipinfo.h"
 
 #include <QJsonObject>
 
