@@ -15,9 +15,9 @@ class IpRulesToolTest : public QObject
 private Q_SLOTS:
     void initTestCase()
     {
+        AccountManager::instance().setTestMode(true);
         account = new MockAccount();
-        AccountManager::instance().addAccount(account, false);
-        AccountManager::instance().selectAccount(account, false);
+        AccountManager::instance().addAccount(account);
     }
 
     void testModel()
@@ -41,4 +41,4 @@ private:
 };
 
 QTEST_MAIN(IpRulesToolTest)
-#include "iprulestooltest.moc"
\ No newline at end of file
+#include "iprulestooltest.moc"
