@@ -49,7 +49,7 @@ public:
 
     void writeToSettings() override;
 
-    void buildFromSettings() override;
+    QCoro::Task<> buildFromSettings() override;
 
     void validateToken() override;
 
