@@ -4,6 +4,8 @@
 
 #include "editor/attachmenteditormodel.h"
 
+#include <QJsonDocument>
+
 #include "account/account.h"
 
 AttachmentEditorModel::AttachmentEditorModel(QObject *parent, AbstractAccount *account)
@@ -57,14 +59,14 @@ QHash<int, QByteArray> AttachmentEditorModel::roleNames() const
 
 QNetworkReply *AttachmentEditorModel::append(const QString &filename)
 {
-    if (rowCount({}) >= 4) {
+    if (rowCount({}) >= m_account->maxMediaAttachments()) {
         return nullptr;
     }
 
     QString localFilename = filename;
     localFilename.remove(QStringLiteral("file://"));
 
-    return m_account->upload(QUrl::fromLocalFile(localFilename), [=](QNetworkReply *reply) {
+    return m_account->upload(QUrl::fromLocalFile(localFilename), [this](QNetworkReply *reply) {
         const auto doc = QJsonDocument::fromJson(reply->readAll());
 
         if (!doc.isObject()) {
@@ -150,6 +152,16 @@ void AttachmentEditorModel::copyFromOther(AttachmentEditorModel *other)
     m_account = other->m_account;
 }
 
+void AttachmentEditorModel::copyFromArray(const QJsonArray &array)
+{
+    beginResetModel();
+    m_attachments.clear();
+    std::ranges::transform(std::as_const(array), std::back_inserter(m_attachments), [this](const QJsonValue &value) {
+        return new Attachment{value.toObject(), this};
+    });
+    endResetModel();
+}
+
 bool AttachmentEditorModel::isLocalFile(const QString &fileName)
 {
     QString localFilename = fileName;
@@ -159,4 +171,14 @@ bool AttachmentEditorModel::isLocalFile(const QString &fileName)
     return info.exists();
 }
 
-#include "moc_attachmenteditormodel.cpp"
\ No newline at end of file
+bool AttachmentEditorModel::isAltTextComplete() const
+{
+    for (auto &attachment : m_attachments) {
+        if (attachment->description().isEmpty()) {
+            return false;
+        }
+    }
+    return true;
+}
+
+#include "moc_attachmenteditormodel.cpp"
