@@ -3,6 +3,8 @@
 
 #pragma once
 
+#include <QJsonDocument>
+
 #include "editor/polleditorbackend.h"
 #include "timeline/post.h"
 
@@ -75,6 +77,8 @@ public:
 public Q_SLOTS:
     void save();
     void edit();
+    void saveDraft();
+    void loadScheduledPost(const QString &id);
 
 Q_SIGNALS:
 
@@ -101,6 +105,8 @@ Q_SIGNALS:
 
     void pollEnabledChanged();
 
+    void scheduledPostLoaded();
+
 private:
     [[nodiscard]] QJsonDocument toJsonDocument() const;
 
@@ -118,4 +124,5 @@ private:
     Post::Visibility m_visibility = Post::Visibility::Public;
     AbstractAccount *m_account = nullptr;
     AttachmentEditorModel *m_attachmentEditorModel = nullptr;
+    QString m_scheduledPostId;
 };
