@@ -5,6 +5,10 @@
 
 #include <QQmlEngine>
 
+#ifdef HAVE_KUNIFIEDPUSH
+#include <kunifiedpush/connector.h>
+#endif
+
 /**
  * @brief Handles miscenallous operations, mostly a glue between C++ and QML.
  */
@@ -80,6 +84,18 @@ public:
      */
     Q_INVOKABLE void clearErrorMessages();
 
+    /**
+     * @brief Register with the KUnifiedPush distributor, if available.
+     */
+    void setupPushNotifications();
+
+#ifdef HAVE_KUNIFIEDPUSH
+    /**
+     * @return The KUnifiedPush connector.
+     */
+    KUnifiedPush::Connector *connector() const;
+#endif
+
     QString endpoint;
 
 Q_SIGNALS:
@@ -91,6 +107,7 @@ Q_SIGNALS:
     void networkErrorOccurred(const QString &errorString);
     void receivedAuthCode(QString authCode);
     void errorMessagesChanged();
+    void pushMessageReceived(const QByteArray &msg);
 
 private:
     explicit NetworkController(QObject *parent = nullptr);
@@ -103,4 +120,8 @@ private:
 
     QByteArray m_systemHttpProxy;
     QByteArray m_systemHttpsProxy;
+
+#ifdef HAVE_KUNIFIEDPUSH
+    KUnifiedPush::Connector *m_connector = nullptr;
+#endif
 };
