@@ -18,6 +18,7 @@ class AbstractTimelineModel : public QAbstractListModel
     Q_OBJECT
 
     Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
+    Q_PROPERTY(bool atEnd READ atEnd NOTIFY atEndChanged)
 
 public:
     enum CustoRoles {
@@ -130,6 +131,22 @@ public:
      */
     void actionPin(const QModelIndex &index, Post *post);
 
+    /**
+     * @brief Mute this @p post's conversation at @p index.
+     */
+    void actionMute(const QModelIndex &index, Post *post);
+
+    /**
+     * @brief Refresh the timeline.
+     * For example, refreshing a thread should load any new replies and statistics.
+     */
+    virtual void refresh() { };
+
+    virtual bool atEnd() const
+    {
+        return false;
+    }
+
 Q_SIGNALS:
     /**
      * @brief Emitted when the timeline loading status has changed.
@@ -142,6 +159,13 @@ Q_SIGNALS:
      */
     void postSourceReady(PostEditorBackend *backend, bool isEdit);
 
+    /**
+     * @brief Emitted when a network error occured when loading this timeline.
+     */
+    void networkErrorOccurred(const QString &message);
+
+    void atEndChanged();
+
 protected:
     QVariant postData(Post *post, int role) const;
 
