@@ -3,6 +3,9 @@
 
 #include "tag.h"
 
+#include <QJsonArray>
+#include <QJsonObject>
+
 using namespace Qt::Literals::StringLiterals;
 
 Tag::Tag(QJsonObject obj)
@@ -48,4 +51,4 @@ QString Tag::name() const
     return m_name;
 }
 
-#include "moc_tag.cpp"
\ No newline at end of file
+#include "moc_tag.cpp"
