@@ -91,6 +91,11 @@ public Q_SLOTS:
      */
     void actionPin(const QModelIndex &index);
 
+    /**
+     * @brief Mute the post's notifications at @p index.
+     */
+    void actionMute(const QModelIndex &index);
+
     /**
      * @brief Reset the timeline posts, and any additional state.
      */
