@@ -24,10 +24,29 @@ public:
 
     [[nodiscard]] QList<KirigamiActionCollection *> actionCollections() const override;
 
+    /**
+     * @brief Visually unchecks the main page actions, if needed.
+     */
+    Q_INVOKABLE void uncheckMainActions();
+
 Q_SIGNALS:
     void accountManagerChanged();
     void configureAccount(AbstractAccount *account);
     void addAccount();
+    void openHomeTimeline();
+    void openNotifications();
+    void openFollowRequests();
+    void openLocalTimeline();
+    void openGlobalTimeline();
+    void openConversations();
+    void openFavorites();
+    void openBookmarks();
+    void openExplore();
+    void openFollowing();
+    void openSearch();
+    void openServerInformation();
+    void openLists();
+    void openProfile();
 
 private:
     void setupActions() override;
@@ -40,4 +59,5 @@ private:
     KirigamiActionCollection *m_accountCollection = nullptr;
     QHash<AbstractAccount *, QAction *> m_switchUserActions;
     QHash<AbstractAccount *, QAction *> m_configureUserActions;
+    QAction *m_dummyAction;
 };
