@@ -1,5 +1,5 @@
-// SPDX-FileCopyrightText: 2021 Tobias Fella <fella@posteo.de>
-// SPDX-License-Identifier: LGPL-2.0-or-later
+// SPDX-FileCopyrightText: 2024 Joshua Goins <josh@redstrate.com>
+// SPDX-License-Identifier: MIT
 
 #pragma once
 
@@ -11,11 +11,11 @@ class AsyncImageResponse final : public QQuickImageResponse
 public:
     AsyncImageResponse(const QString &id, const QSize &requestedSize, QThreadPool *pool);
     void handleDone(QImage image);
-    QQuickTextureFactory *textureFactory() const override;
+    [[nodiscard]] QQuickTextureFactory *textureFactory() const override;
     QImage m_image;
 };
 
-class BlurhashImageProvider : public QQuickAsyncImageProvider
+class BlurHashImageProvider : public QQuickAsyncImageProvider
 {
 public:
     QQuickImageResponse *requestImageResponse(const QString &id, const QSize &requestedSize) override;
