@@ -3,8 +3,8 @@
 
 #pragma once
 
+#include <QQmlEngine>
 #include <QSortFilterProxyModel>
-#include <QtQml>
 
 class LimiterModel : public QSortFilterProxyModel
 {
@@ -32,4 +32,4 @@ protected:
 private:
     int m_maximumCount = 0;
     int m_extraCount = 0;
-};
\ No newline at end of file
+};
